@@ -8,21 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_cloudfront._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_mediastore._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cloudfront-mediastore",
-    "1.181.1",
+    "2.0.0",
     __name__[0:-6],
-    "aws-cloudfront-mediastore@1.181.1.jsii.tgz",
+    "aws-cloudfront-mediastore@2.0.0.jsii.tgz",
 )
 
 __all__ = [
